/**********************************************************
 * MIDI Out Module for Yamaha Electone FX/FS Series organs
 * Tim Singer, 2012-2013
 * Project page: http://tsstech.org/electronics/fxmidi.html
 * 
 * analog.c:  Aftertouch and expression pedal
 **********************************************************/
#include "common.h"
#include "analog.h"
#include "uart.h"

//==========================================================
// analog_init()
//  Configures and starts analog module:
//   4-channel continuous conversion on AN0-AN3.
//  Results always available in ADC1BUF0-ADC1BUF3.
//==========================================================
void analog_init() {

    //Basic analog enable code adapted from reference guide and app note

    _FORM   = 0;    // Data Output Format: Unsigned integer
    _SSRC   = 7;    // Internal Counter (SAMC) ends sampling and starts convertion
    _ASAM   = 0;    // ADC Sample Control: Sampling begins immediately after conversion
    _AD12B  = 0;    // 10-bit ADC operation

    _CHPS  = 3;     // Converts CH0-3
    
    _ADRC=0;        // ADC Clock is derived from Systems Clock
    _SAMC=10;       // Auto Sample Time = 2*Tad
    _ADCS=30;       // ADC Conversion Clock Tad=Tcy*(ADCS+1)= (1/40M)*3 = 75ns (13.3Mhz)
                    // ADC Conversion Time for 10-bit Tc=12*Tab =  900ns (1.1MHz)
                
    _ADDMABM = 0;   // DMA buffers are not enabled
    _SMPI    = 3;   // Interrupt after every 4th conversion
    _ADDMAEN  = 0;  // Converts in ADC1BUF0

    //AD1CHS0/AD1CHS123: A/D Input Select Register
    _CH0SA=3;       // MUXA +ve input selection (AIN3) for CH0
    _CH0NA=0;       // MUXA -ve input selection (Vref-) for CH0

    _CH123SA=0;     // MUXA +ve input selection (AIN1/2/3) for CH1/2/3
    _CH123NA=0;     // MUXA -ve input selection (Vref-) for CH1/2/3

    _AD1IF = 0;     // Clear the A/D interrupt flag bit
    _AD1IE = 0;     // Do Not Enable A/D interrupt 
       
    _ADON = 1;      // Turn on the A/D converter

    _ASAM = 1;      // Sampling begins immediately after last conversion. SAMP bit is auto-set
}

/*static void encode(uint16 sample) {
    uart_send_string("   ");
    sample /= 31;
    uart_print_int(sample/10);
    uart_send_byte('.');
    uart_print_int(sample%10);
}

void analog_read_and_print() {

    //_AD1IF = 0;

    uart_send_string("\r Sample:");
    uart_print_int(ADC1BUF0); uart_send_string(" ");
    uart_print_int(ADC1BUF1); uart_send_string(" ");
    uart_print_int(ADC1BUF2); uart_send_string(" ");
    uart_print_int(ADC1BUF3); uart_send_string(" ");
}
*/
