#include "p24ep64gp202.h"
#include "blink_led.h"
#include "midi_out.h"
#include "uart.h"
#include "analog.h"
#include "shiftreg.h"
#include "kbscan.h"

static unsigned char song[];
static int prev;
static int pos;

static int play(int position, int velocity) {
	unsigned char i;
	unsigned char n = song[position];

	if(n == 0) return position;
	++position;

	for(i = 0; i < n; i++) {
		midi_send_note_on(0,song[position],velocity);
		++position;
	}

	return position;
}

static void next_note() {
	if(pos != 0) prev = play(prev, 0);
	pos = play(pos, 127);
	analog_read_and_print();
	uart_send_string(" ");
	uart_print_hex(shiftreg_read());
	uart_send_string(" ");
	uart_print_hex(shiftreg_read2());
	uart_send_string(" ");
	uart_print_hex(shiftreg_read2());
	uart_send_string(" CLcount:");
	
	kbscan_read();
	uart_print_hex(kbscan_cl_count);

	uart_send_string(" RA:");
	uart_print_hex(PORTA);
	uart_send_string(" RB:");
	uart_print_hex(PORTB);
}

void blink_led_init() {
	prev = pos = 0;

	//Initialize timer1 (16-bit) for 0.25sec operation at 60MHz
	//Scaled by: 256
	//Period at scale 256: 58594
	TMR1=0;
	PR1=40000; //58594; //48828;	// 5/6 * 1/4 second
	_T1IE = 0;
	_T1IF = 0;
	T1CON = 0x8030;  //10000000 00110000
}

void blink_led_run() {
	while(1) {
		//LATB ^= 0x20;
		next_note();

		/*
		LATB ^= 0x4000;
		if(!_LATB14) {
			LATB ^= 0x1000;
			if(!_LATB12) {
				LATB ^= 0x8000;	//LATB15
			}
		}
		next_note();
		*/
		while(!_T1IF) { }
		_T1IF = 0;
	}
}

#define A2  57
#define Cs3 61
#define D3  62
#define E3  64
#define F3  65
#define G3  67
#define A3  69
#define Bb3 70
#define B3  71
#define C4  72
#define Cs4 73
#define D4  74
#define E4  76
#define F4  77
#define G4  79
#define A4  81

//Oberwerk opening bars of BWV538
static unsigned char song[] = {
	1,D3,     1,Cs3,    1,D3,     1,A2,     1,D3,    1,A2,    1,E3,     1,A2,
	2,D4,F3,  2,Cs4,E3, 2,D4,F3,  2,A3,D3,  2,D4,F3, 2,A3,D3, 2,E4,G3,  2,A3,D3,
	2,F4,A3,  2,E4,G3,  2,F4,A3,  2,D4,F3,  2,F4,A3, 2,D4,F3, 2,G4,Bb3, 2,D4,F3,
	2,E4,G3,  2,D4,F3,  2,E4,G3,  2,C4,E3,  2,E4,G3, 2,C4,E3, 2,F4,A3,  2,C4,E3,
	2,D4,F3,  2,C4,E3,  2,D4,F3,  2,B3,D3,  2,D4,F3, 2,B3,D3, 2,E4,G3,  2,B3,D3,
	2,Cs4,E3, 2,B3,D3,  2,Cs4,E3, 2,A3,Cs3, 2,D4,A2, 2,A3,F3, 2,E4,A2,  2,A3,Cs3,
	2,F4,A2,  2,A3,D3,  2,E4,A2,  2,A3,Cs3, 2,F4,A2, 2,A3,D3, 2,G4,A2,  2,A3,E3,
	2,A4,F3,  2,Cs4,E3, 2,D4,F3,  2,Bb3,G3, 2,A3,F3, 2,D4,D3, 2,G3,E3,  2,Cs4,A2,
	5,A2,D3,F3,A3,D4,
	0
};
