/**********************************************************
 * MIDI Out Module for Yamaha Electone FX/FS Series organs
 * Tim Singer, 2012
 * Project page: http://tsstech.org/electronics/fxmidi.html
 * 
 * cpanel.h:  Reading the control panel and drawbars
 **********************************************************/

//Configures and starts the control panel eavesdropping system (SPI2, INT2, CN)
void cpanel_init();

extern uint16 fx_cpanel_bitmask[65];        //Bitmask (AND mask) indicating which bits to read: [0]..[28] = buttons, [29]..[57]=LEDs, [58]..[64]=drawbars
extern volatile uint16 cpanel_buffer[65];   //Masked data read from control panel and drawbars: [0]..[28] = buttons, [29]..[57]=LEDs, [58]..[64]=drawbars
extern volatile bool fx_cpanel_changed;     //Flag set when the eavesdropping system detects a change in the masked bits

//Bit order for bitmask and buffer:
//  The data stream is most significant bit first, in 8-bit groups.
//  Data is written into sequential bytes in memory, but read as words for efficiency.  Since the PIC is little-endian, the byte order is swapped.
//  For example, if the data stream is: 12 34 56 78 9A BC DE F0..., then the buffer stores { 0x3412, 0x7856, 0xBC9A, 0xF0DE, ... }

