/**********************************************************
 * MIDI Out Module for Yamaha Electone FX/FS Series organs
 * Tim Singer, 2012
 * Project page: http://tsstech.org/electronics/fxmidi.html
 * 
 * debug.c:  Serial debug console
 **********************************************************/
#include "common.h"
#include "uart.h"
#include "shiftreg.h"
#include "analog.h"
#include "cpanel.h"

//==========================================================
// debug_init()
//  Configures and starts the periodic debug output.
//  Uses peripherals: T1
//==========================================================
void debug_init() {
    TMR1=0;
    PR1=58594;  //1/4 second
    _T1IP = 1;
    _T1IE = 1;
    _T1IF = 0;
    T1CON = 0x8030;  //10000000 00110000
}

//==========================================================
// Interrupt handler: T1
// Triggered 3-4 times per second
// Outputs debug data to the serial console
//==========================================================
void __attribute__((interrupt,no_auto_psv)) _T1Interrupt() {
    uint16 i;
    //uint16 count = spi_count;
    _T1IF = 0;

    uart_send_string("\r\n\r\nMDO:");
    for(i = 0; i < 57; ++i) {
        uart_send_string(" ");
        uart_print_hex8(((byte*)fx_cpanel_bitmask)[i]);
    }
    uart_send_string("\r\nMDi:");
    for(i = 58; i < 115; ++i) {
        uart_send_string(" ");
        uart_print_hex8(((byte*)fx_cpanel_bitmask)[i]);
    }


    uart_send_string("\r\nSDO:");
    for(i = 0; i < 57; ++i) {
        uart_send_string(" ");
        uart_print_hex8(((byte*)cpanel_buffer)[i]);
    }
    uart_send_string("\r\nSDi:");
    for(i = 58; i < 115; ++i) {
        uart_send_string(" ");
        uart_print_hex8(((byte*)cpanel_buffer)[i]);
    }

    /*
    uart_send_string("\rRA:"); uart_print_hex(PORTA & 0xC);
    uart_send_string(" RB:"); uart_print_hex(PORTB & 0xFF1C);

    //uart_send_string(" T5:"); uart_print_hex(t5count); t5count = 0;
    //uart_send_string(" DMA0:"); uart_print_hex(dma0count); dma0count = 0;

    uart_send_string(" KS:");
    for(i = 0; i < 13; ++i) {
        uart_print_hex(key_state[i]);
        uart_send_string(" ");
    }

    analog_read_and_print();
    */

    /*
    shiftreg_read_dma();

    uart_send_string(" RS:"); uart_print_hex(spi_dma_buffer[0]);
    uart_send_string(" "); uart_print_hex(spi_dma_buffer[1]);
    uart_send_string(" "); uart_print_hex(spi_dma_buffer[2]);
    uart_send_string(" "); uart_print_hex(spi_dma_buffer[3]);
    */
}
