/**********************************************************
 * MIDI Out Module for Yamaha Electone FX/FS Series organs
 * Tim Singer, 2012
 * Project page: http://tsstech.org/electronics/fxmidi.html
 * 
 * electone.h:  Electone model-specific MIDI configuration
 **********************************************************/

#include "fx20.h"

typedef struct analog_config {
    byte message_type;        //Message type (0 for nothing, 0xD0 for aftertouch, 0xB0 for controller) and channel
    byte message_data;        //Controller number (only valid for type 0xB0)
    uint16 max_value;        //Calibration value
} analog_config;

typedef enum ControlType {
    type_button = 0,            //Triggers on press/release
    type_led = 0,               //Triggers on light/dark
    type_slider = 1,            //Triggers on physical position change
    type_motor = 1,             //Triggers on logical position change
    type_lever = 2,             //Triggers on physical position change
    type_digit_gefdacb = 3,     //Triggers on value change (0..9, dark)
    type_encoder = 4,           //Triggers on increment/decrement

    subtype_momentary = 0,      //For buttons/LEDs:  Activate on, deactivate off
    subtype_persistent = 0x10,  //For buttons/LEDs:  Activate on, deactivate NOP
    subtype_toggle = 0x20,      //For buttons/LEDs:  Activate toggle, deactivate NOP
    subtype_progressive = 0x30, //For transpose buttons:  Activate increment
} ControlType;

typedef enum SpecialMessage {
    loco = 0,                   //ch = keyboard ID
    transpose_up = 1,           //ch = keyboard ID, data1=amt - not applied if top note > (127-amt)
    transpose_down = 2,         //ch = keyboard ID, data1=amt - not applied if bottom note < amt
    midi_ch_override = 3,       //ch = keyboard ID, data1=new channel (0..15)
    midi_ch_reset = 4,          //ch = keyboard ID
    coupler_iii_p16 = 5,        //Hard coupler: couples solo keys to pedal 16' down
} SpecialMessage;

typedef struct control_config {
    uint16 bit_index;           //From beginning of SDi[57]+SDO[57]+TDi[14]; 0xFFFF is end indicator
    byte control_type;
    byte message;               //MIDI status byte (message and channel); types 0..7 are special functions
    byte data1;
    byte data2;
} control_config;

typedef struct electone_config {
    byte channel[16];                   //MIDI channel by octave pin
    byte base_pitch[16];                //MIDI base pitch by octave pin
    byte pitch_map[13];                 //MIDI pitch offset by scan phase (+3 reserved bytes)
    analog_config analog_map[4];        //MIDI message map for analog controllers
    control_config control_map[256];    //Control map
} electone_config;

//Default config for FX_20
extern const electone_config fx20_default_config;
