/**********************************************************
 * MIDI Out Module for Yamaha Electone FX/FS Series organs
 * Tim Singer, 2012
 * Project page: http://tsstech.org/electronics/fxmidi.html
 * 
 * fx20.h:  Model-specific information for FX-20
 **********************************************************/

//==========================================================
// All FX-20 control bit indices
//==========================================================
typedef enum fx20_controls {
    fx20_control_kneeswitch = 1,
    fx20_control_footswitch,

    fx20_control_regpack_writeprotect = 10,
    fx20_control_regpack_present = 12,
    fx20_control_regpack_write = 17,
    fx20_control_regpack_confirm,
    fx20_control_regpack_read,

    fx20_control_abc_pedalmemory = 24,
    fx20_control_abc_lowermemory,
    fx20_control_abc_multibass3,
    fx20_control_abc_customabc,
    fx20_control_abc_multibass2,
    fx20_control_abc_fingeredchord,
    fx20_control_abc_multibass1,
    fx20_control_abc_singlefingerchord,
    fx20_control_abc_multibassnormal,
    fx20_control_abc_normal,

    fx20_control_sustain_pedal = 36,
    fx20_control_sustain_lower = 40,
    fx20_control_sustain_upper = 44,
    fx20_control_sustain_pedalsustain = 48,
    fx20_control_sustain_playassist,
    fx20_control_sustain_lowersustain,
    fx20_control_sustain_uppersustain,

    fx20_control_pcust_volume = 52,
    fx20_control_pcust_brilliance = 56,
    fx20_control_pcust_cosmic = 60,
    fx20_control_pcust_tuba,
    fx20_control_pcust_vocal,
    fx20_control_pcust_contrabass4,
    fx20_control_pcust_electricbass3,
    fx20_control_pcust_contrabass3,
    fx20_control_pcust_electricbass2,
    fx20_control_pcust_contrabass2,
    fx20_control_pcust_electricbass1,
    fx20_control_pcust_contrabass1,

    fx20_control_pcombi_volume = 72,
    fx20_control_pcombi_preset2 = 76,
    fx20_control_pcombi_memory,
    fx20_control_pcombi_preset1,
    fx20_control_pcombi_combilever,

    fx20_control_ensemble_lcust = 80,
    fx20_control_ensemble_ucust,
    fx20_control_ensemble_lspec,
    fx20_control_ensemble_uspec,
    fx20_control_ensemble_lorch,
    fx20_control_ensemble_uorch,
    fx20_control_ensemble_lcombi,
    fx20_control_ensemble_ucombi,

    fx20_control_lspec_volume = 88,
    fx20_control_lspec_touchtone = 92,
    fx20_control_lspec_jazzguitar,
    fx20_control_lspec_cosmic3,
    fx20_control_lspec_acousticguitar,
    fx20_control_lspec_cosmic2,
    fx20_control_lspec_harp,
    fx20_control_lspec_cosmic1,
    fx20_control_lspec_harpsichord,
    fx20_control_lspec_brass2,
    fx20_control_lspec_electricpiano,
    fx20_control_lspec_brass1,
    fx20_control_lspec_piano,

    fx20_control_lorch_volume = 104,
    fx20_control_lorch_touchtone = 108,
    fx20_control_lorch_reed,
    fx20_control_lorch_presetvibrato,
    fx20_control_lorch_brass3,
    fx20_control_lorch_cosmic,
    fx20_control_lorch_brass2,
    fx20_control_lorch_spice2,
    fx20_control_lorch_brass1,
    fx20_control_lorch_spice1,
    fx20_control_lorch_strings3,
    fx20_control_lorch_vocal2,
    fx20_control_lorch_strings2,
    fx20_control_lorch_vocal1,
    fx20_control_lorch_strings1,

    fx20_control_lcombi_volume = 124,
    fx20_control_lcombi_preset4 = 128,
    fx20_control_lcombi_memory3,
    fx20_control_lcombi_preset3,
    fx20_control_lcombi_memory2,
    fx20_control_lcombi_preset2,
    fx20_control_lcombi_memory1,
    fx20_control_lcombi_preset1,
    fx20_control_lcombi_combilever,

    fx20_control_tempo_dial = 168,

    fx20_control_autorhythm_volume = 176,
    fx20_control_autorhythm_balance = 180,
    fx20_control_autorhythm_program4 = 184,
    fx20_control_autorhythm_16bar,
    fx20_control_autorhythm_program3,
    fx20_control_autorhythm_8bar,
    fx20_control_autorhythm_program2,
    fx20_control_autorhythm_4bar,
    fx20_control_autorhythm_program1,
    fx20_control_autorhythm_normal,

    fx20_control_playassist_countermelody = 196,
    fx20_control_playassist_duet,
    fx20_control_playassist_melodyonchord2,
    fx20_control_playassist_melodyonchord1,
    fx20_control_playassist_uspec,
    fx20_control_playassist_uorch,
    fx20_control_playassist_ucombi,
    fx20_control_playassist_keyset,

    fx20_control_rc2_volume = 204,
    fx20_control_rc2_phase = 208,
    fx20_control_rc2_jazzguitar,
    fx20_control_rc2_solidguitar,
    fx20_control_rc2_brass,

    fx20_control_rc1_volume = 212,
    fx20_control_rc1_phase = 216,
    fx20_control_rc1_jazzguitar,
    fx20_control_rc1_solidguitar,
    fx20_control_rc1_piano,

    fx20_control_autoarpeggio_volume = 220,
    fx20_control_autoarpeggio_harp = 224,
    fx20_control_autoarpeggio_harpsichord,
    fx20_control_autoarpeggio_strings,
    fx20_control_autoarpeggio_piano,
    fx20_control_autoarpeggio_8,
    fx20_control_autoarpeggio_4,
    fx20_control_autoarpeggio_7,
    fx20_control_autoarpeggio_3,
    fx20_control_autoarpeggio_6,
    fx20_control_autoarpeggio_2,
    fx20_control_autoarpeggio_5,
    fx20_control_autoarpeggio_1,

    fx20_control_ulcust_volume = 236,
    fx20_control_ulcust_touchtone = 240,
    fx20_control_ulcust_hawaiianguitar,
    fx20_control_ulcust_touchvibrato,
    fx20_control_ulcust_jazzguitar,
    fx20_control_ulcust_presetvibrato,
    fx20_control_ulcust_violin,
    fx20_control_ulcust_cosmic4,
    fx20_control_ulcust_trombone,
    fx20_control_ulcust_cosmic3,
    fx20_control_ulcust_trumpet,
    fx20_control_ulcust_cosmic2,
    fx20_control_ulcust_saxophone,
    fx20_control_ulcust_cosmic1,
    fx20_control_ulcust_clarinet,
    fx20_control_ulcust_vocal,
    fx20_control_ulcust_oboe,
    fx20_control_ulcust_bassguitar,
    fx20_control_ulcust_flute,

    fx20_control_uspec_volume = 260,
    fx20_control_uspec_touchtone = 264,
    fx20_control_uspec_mandolin,
    fx20_control_uspec_cosmic,
    fx20_control_uspec_marimba,
    fx20_control_uspec_brass2,
    fx20_control_uspec_vibraphone,
    fx20_control_uspec_brass1,
    fx20_control_uspec_celeste,
    fx20_control_uspec_jazzguitar,
    fx20_control_uspec_harpsichord,
    fx20_control_uspec_banjo,
    fx20_control_uspec_piano,

    fx20_control_uorch_volume = 276,
    fx20_control_uorch_touchtone = 280,
    fx20_control_uorch_brass3,
    fx20_control_uorch_presetvibrato,
    fx20_control_uorch_brass2,
    fx20_control_uorch_spice2,
    fx20_control_uorch_brass1,
    fx20_control_uorch_spice1,
    fx20_control_uorch_strings4,
    fx20_control_uorch_vocal,
    fx20_control_uorch_strings3,
    fx20_control_uorch_reed2,
    fx20_control_uorch_strings2,
    fx20_control_uorch_reed1,
    fx20_control_uorch_strings1,

    fx20_control_ucombi_volume = 296,
    fx20_control_ucombi_preset4 = 300,
    fx20_control_ucombi_memory3,
    fx20_control_ucombi_preset3,
    fx20_control_ucombi_memory2,
    fx20_control_ucombi_preset2,
    fx20_control_ucombi_memory1,
    fx20_control_ucombi_preset1,
    fx20_control_ucombi_combilever,

    fx20_control_autorhythm_4 = 308,
    fx20_control_autorhythm_2,
    fx20_control_autorhythm_3,
    fx20_control_autorhythm_1,
    fx20_control_autorhythm_16beat,
    fx20_control_autorhythm_8beat2,
    fx20_control_autorhythm_disco,
    fx20_control_autorhythm_8beat1,
    fx20_control_autorhythm_latinrock,
    fx20_control_autorhythm_slowrock,
    fx20_control_autorhythm_samba,
    fx20_control_autorhythm_bounce,
    fx20_control_autorhythm_bossanova,
    fx20_control_autorhythm_swing,
    fx20_control_autorhythm_latin2,
    fx20_control_autorhythm_ballad,
    fx20_control_autorhythm_latin1,
    fx20_control_autorhythm_waltz,
    fx20_control_autorhythm_tango,
    fx20_control_autorhythm_march,

    fx20_control_solo_slidecontrol = 328,
    fx20_control_solo_volume = 332,
    fx20_control_solo_brilliance = 336,
    fx20_control_solo_touchtone = 340,
    fx20_control_solo_up,
    fx20_control_solo_touchvibrato,
    fx20_control_solo_normal,
    fx20_control_solo_presetvibrato,
    fx20_control_solo_down,
    fx20_control_solo_cosmic2,
    fx20_control_solo_horn,
    fx20_control_solo_cosmic1,
    fx20_control_solo_trumpet2,
    fx20_control_solo_vocal,
    fx20_control_solo_trumpet1,
    fx20_control_solo_harmonica,
    fx20_control_solo_saxophone,
    fx20_control_solo_jazzguitar,
    fx20_control_solo_clarinet,
    fx20_control_solo_cello,
    fx20_control_solo_oboe,
    fx20_control_solo_violin,
    fx20_control_solo_flute,
    fx20_control_solo_trombone,
    fx20_control_solo_piccolo,
    fx20_control_solo_coupler = 363,
    fx20_control_solo_detune,

    fx20_control_rhythm_breakvari3 = 368,
    fx20_control_rhythm_breakvari2,
    fx20_control_rhythm_breakvari1,
    fx20_control_rhythm_break = 372,
    fx20_control_rhythm_start,
    fx20_control_rhythm_synchrostart,

    fx20_control_footswitch_breakvari = 376,
    fx20_control_footswitch_rhythmstop,
    fx20_control_footswitch_glide,

    fx20_control_sliderdrive = 379,
    fx20_control_manualbalance = 380,
    fx20_control_pedaldrc = 387,

    fx20_control_preset_8 = 388,
    fx20_control_preset_7,
    fx20_control_preset_6,
    fx20_control_preset_5,
    fx20_control_preset_4,
    fx20_control_preset_3,
    fx20_control_preset_2,
    fx20_control_preset_1,
    fx20_control_preset_r,
    fx20_control_preset_d,
    fx20_control_preset_c,
    fx20_control_preset_m,

    fx20_control_symphonic_lorch = 400,
    fx20_control_symphonic_uorch,
    fx20_control_symphonic_lcombi,
    fx20_control_symphonic_ucombi,

    fx20_control_tremolo_lorch = 404,
    fx20_control_tremolo_uorch,
    fx20_control_tremolo_lcombi,
    fx20_control_tremolo_ucombi,

    fx20_control_effect_tremolo = 408,
    fx20_control_effect_symphonic,
    fx20_control_effect_chorus,
    fx20_control_effect_celeste,
    fx20_control_effect_reverb,

    fx20_control_sequence_forward = 419,
    fx20_control_sequence_back,
    fx20_control_sequence_end,
    fx20_control_sequence_blank,
    fx20_control_sequence_record,
    fx20_control_sequence_on,

    fx20_control_combi_timbrevari = 425,
    fx20_control_combi_responsefast,
    fx20_control_combi_programset,

    fx20_control_tremolo_preset = 436,
    fx20_control_tremolo_player,
    fx20_control_tremolo_lever,
    fx20_control_tremolo_set,
    fx20_control_tremolo_speed = 441,
    fx20_control_tremolo_depth = 445,
    fx20_control_tremolo_delay = 449,
    fx20_control_tremolo_touchdepth = 453,

    fx20_signal_op_pedaldrc = 456,
    fx20_signal_op_celeste = 459,
    fx20_signal_op_tonecabinet_orch,
    fx20_signal_op_tonecabinet_combi,
    fx20_signal_op_chorus,
    fx20_signal_op_tremolo,
    fx20_signal_op_rc2 = 467,
    fx20_signal_op_rc1 = 469,
    fx20_signal_op_motor = 471,

    fx20_signal_regpack_write = 473,
    fx20_signal_regpack_confirm,
    fx20_signal_regpack_read,
    fx20_signal_regpack_memoryready = 477,
    fx20_signal_regpack_error,

    fx20_signal_abc_pedalmemory = 480,
    fx20_signal_abc_lowermemory,
    fx20_signal_abc_multibass3,
    fx20_signal_abc_customabc,
    fx20_signal_abc_multibass2,
    fx20_signal_abc_fingeredchord,
    fx20_signal_abc_multibass1,
    fx20_signal_abc_singlefingerchord,
    fx20_signal_abc_multibassnormal,
    fx20_signal_abc_normal,

    fx20_signal_sustain_pedal = 492,
    fx20_signal_sustain_lower = 496,
    fx20_signal_sustain_upper = 500,
    fx20_signal_sustain_pedalsustain = 504,
    fx20_signal_sustain_playassist,
    fx20_signal_sustain_lowersustain,
    fx20_signal_sustain_uppersustain,

    fx20_signal_pcust_volume = 508,
    fx20_signal_pcust_brilliance = 512,
    fx20_signal_pcust_cosmic = 516,
    fx20_signal_pcust_tuba,
    fx20_signal_pcust_vocal,
    fx20_signal_pcust_contrabass4,
    fx20_signal_pcust_electricbass3,
    fx20_signal_pcust_contrabass3,
    fx20_signal_pcust_electricbass2,
    fx20_signal_pcust_contrabass2,
    fx20_signal_pcust_electricbass1,
    fx20_signal_pcust_contrabass1,

    fx20_signal_pcombi_volume = 528,
    fx20_signal_pcombi_preset2 = 532,
    fx20_signal_pcombi_memory,
    fx20_signal_pcombi_preset1,
    fx20_signal_pcombi_combilever,

    fx20_signal_ensemble_lcust = 536,
    fx20_signal_ensemble_ucust,
    fx20_signal_ensemble_lspec,
    fx20_signal_ensemble_uspec,
    fx20_signal_ensemble_lorch,
    fx20_signal_ensemble_uorch,
    fx20_signal_ensemble_lcombi,
    fx20_signal_ensemble_ucombi,

    fx20_signal_lspec_volume = 544,
    fx20_signal_lspec_touchtone = 548,
    fx20_signal_lspec_jazzguitar,
    fx20_signal_lspec_cosmic3,
    fx20_signal_lspec_acousticguitar,
    fx20_signal_lspec_cosmic2,
    fx20_signal_lspec_harp,
    fx20_signal_lspec_cosmic1,
    fx20_signal_lspec_harpsichord,
    fx20_signal_lspec_brass2,
    fx20_signal_lspec_electricpiano,
    fx20_signal_lspec_brass1,
    fx20_signal_lspec_piano,

    fx20_signal_lorch_volume = 560,
    fx20_signal_lorch_touchtone = 564,
    fx20_signal_lorch_reed,
    fx20_signal_lorch_presetvibrato,
    fx20_signal_lorch_brass3,
    fx20_signal_lorch_cosmic,
    fx20_signal_lorch_brass2,
    fx20_signal_lorch_spice2,
    fx20_signal_lorch_brass1,
    fx20_signal_lorch_spice1,
    fx20_signal_lorch_strings3,
    fx20_signal_lorch_vocal2,
    fx20_signal_lorch_strings2,
    fx20_signal_lorch_vocal1,
    fx20_signal_lorch_strings1,

    fx20_signal_lcombi_volume = 580,
    fx20_signal_lcombi_preset4 = 584,
    fx20_signal_lcombi_memory3,
    fx20_signal_lcombi_preset3,
    fx20_signal_lcombi_memory2,
    fx20_signal_lcombi_preset2,
    fx20_signal_lcombi_memory1,
    fx20_signal_lcombi_preset1,
    fx20_signal_lcombi_combilever,

    fx20_signal_tempo_digit4 = 592,
    fx20_signal_tempo_decimal = 599,
    fx20_signal_tempo_digit3 = 600,
    fx20_signal_tempo_digit2 = 608,
    fx20_signal_tempo_digit1 = 616,
    fx20_signal_tempo_barbeat = 623,
    fx20_signal_tempo_dial = 624,

    fx20_signal_autorhythm_volume = 632,
    fx20_signal_autorhythm_balance = 636,
    fx20_signal_autorhythm_program4 = 640,
    fx20_signal_autorhythm_16bar,
    fx20_signal_autorhythm_program3,
    fx20_signal_autorhythm_8bar,
    fx20_signal_autorhythm_program2,
    fx20_signal_autorhythm_4bar,
    fx20_signal_autorhythm_program1,
    fx20_signal_autorhythm_normal,

    fx20_signal_playassist_countermelody = 652,
    fx20_signal_playassist_duet,
    fx20_signal_playassist_melodyonchord2,
    fx20_signal_playassist_melodyonchord1,
    fx20_signal_playassist_uspec,
    fx20_signal_playassist_uorch,
    fx20_signal_playassist_ucombi,
    fx20_signal_playassist_keyset,

    fx20_signal_rc2_volume = 660,
    fx20_signal_rc2_phase = 664,
    fx20_signal_rc2_jazzguitar,
    fx20_signal_rc2_solidguitar,
    fx20_signal_rc2_brass,

    fx20_signal_rc1_volume = 668,
    fx20_signal_rc1_phase = 672,
    fx20_signal_rc1_jazzguitar,
    fx20_signal_rc1_solidguitar,
    fx20_signal_rc1_piano,

    fx20_signal_autoarpeggio_volume = 676,
    fx20_signal_autoarpeggio_harp = 680,
    fx20_signal_autoarpeggio_harpsichord,
    fx20_signal_autoarpeggio_strings,
    fx20_signal_autoarpeggio_piano,
    fx20_signal_autoarpeggio_8,
    fx20_signal_autoarpeggio_4,
    fx20_signal_autoarpeggio_7,
    fx20_signal_autoarpeggio_3,
    fx20_signal_autoarpeggio_6,
    fx20_signal_autoarpeggio_2,
    fx20_signal_autoarpeggio_5,
    fx20_signal_autoarpeggio_1,

    fx20_signal_ulcust_volume = 692,
    fx20_signal_ulcust_touchtone = 696,
    fx20_signal_ulcust_hawaiianguitar,
    fx20_signal_ulcust_touchvibrato,
    fx20_signal_ulcust_jazzguitar,
    fx20_signal_ulcust_presetvibrato,
    fx20_signal_ulcust_violin,
    fx20_signal_ulcust_cosmic4,
    fx20_signal_ulcust_trombone,
    fx20_signal_ulcust_cosmic3,
    fx20_signal_ulcust_trumpet,
    fx20_signal_ulcust_cosmic2,
    fx20_signal_ulcust_saxophone,
    fx20_signal_ulcust_cosmic1,
    fx20_signal_ulcust_clarinet,
    fx20_signal_ulcust_vocal,
    fx20_signal_ulcust_oboe,
    fx20_signal_ulcust_bassguitar,
    fx20_signal_ulcust_flute,

    fx20_signal_uspec_volume = 716,
    fx20_signal_uspec_touchtone = 720,
    fx20_signal_uspec_mandolin,
    fx20_signal_uspec_cosmic,
    fx20_signal_uspec_marimba,
    fx20_signal_uspec_brass2,
    fx20_signal_uspec_vibraphone,
    fx20_signal_uspec_brass1,
    fx20_signal_uspec_celeste,
    fx20_signal_uspec_jazzguitar,
    fx20_signal_uspec_harpsichord,
    fx20_signal_uspec_banjo,
    fx20_signal_uspec_piano,

    fx20_signal_uorch_volume = 732,
    fx20_signal_uorch_touchtone = 736,
    fx20_signal_uorch_brass3,
    fx20_signal_uorch_presetvibrato,
    fx20_signal_uorch_brass2,
    fx20_signal_uorch_spice2,
    fx20_signal_uorch_brass1,
    fx20_signal_uorch_spice1,
    fx20_signal_uorch_strings4,
    fx20_signal_uorch_vocal,
    fx20_signal_uorch_strings3,
    fx20_signal_uorch_reed2,
    fx20_signal_uorch_strings2,
    fx20_signal_uorch_reed1,
    fx20_signal_uorch_strings1,

    fx20_signal_ucombi_volume = 752,
    fx20_signal_ucombi_preset4 = 756,
    fx20_signal_ucombi_memory3,
    fx20_signal_ucombi_preset3,
    fx20_signal_ucombi_memory2,
    fx20_signal_ucombi_preset2,
    fx20_signal_ucombi_memory1,
    fx20_signal_ucombi_preset1,
    fx20_signal_ucombi_combilever,

    fx20_signal_autorhythm_4 = 764,
    fx20_signal_autorhythm_2,
    fx20_signal_autorhythm_3,
    fx20_signal_autorhythm_1,
    fx20_signal_autorhythm_16beat,
    fx20_signal_autorhythm_8beat2,
    fx20_signal_autorhythm_disco,
    fx20_signal_autorhythm_8beat1,
    fx20_signal_autorhythm_latinrock,
    fx20_signal_autorhythm_slowrock,
    fx20_signal_autorhythm_samba,
    fx20_signal_autorhythm_bounce,
    fx20_signal_autorhythm_bossanova,
    fx20_signal_autorhythm_swing,
    fx20_signal_autorhythm_latin2,
    fx20_signal_autorhythm_ballad,
    fx20_signal_autorhythm_latin1,
    fx20_signal_autorhythm_waltz,
    fx20_signal_autorhythm_tango,
    fx20_signal_autorhythm_march,

    fx20_signal_solo_slidesignal = 784,
    fx20_signal_solo_volume = 788,
    fx20_signal_solo_brilliance = 792,
    fx20_signal_solo_touchtone = 796,
    fx20_signal_solo_up,
    fx20_signal_solo_touchvibrato,
    fx20_signal_solo_normal,
    fx20_signal_solo_presetvibrato,
    fx20_signal_solo_down,
    fx20_signal_solo_cosmic2,
    fx20_signal_solo_horn,
    fx20_signal_solo_cosmic1,
    fx20_signal_solo_trumpet2,
    fx20_signal_solo_vocal,
    fx20_signal_solo_trumpet1,
    fx20_signal_solo_harmonica,
    fx20_signal_solo_saxophone,
    fx20_signal_solo_jazzguitar,
    fx20_signal_solo_clarinet,
    fx20_signal_solo_cello,
    fx20_signal_solo_oboe,
    fx20_signal_solo_violin,
    fx20_signal_solo_flute,
    fx20_signal_solo_trombone,
    fx20_signal_solo_piccolo,
    fx20_signal_solo_coupler = 819,
    fx20_signal_solo_detune,

    fx20_signal_rhythm_breakvari3 = 824,
    fx20_signal_rhythm_breakvari2,
    fx20_signal_rhythm_breakvari1,
    fx20_signal_rhythm_break = 828,
    fx20_signal_rhythm_start,
    fx20_signal_rhythm_synchrostart,

    fx20_signal_footswitch_breakvari = 832,
    fx20_signal_footswitch_rhythmstop,
    fx20_signal_footswitch_glide,

    fx20_signal_sliderdrive = 835,
    fx20_signal_manualbalance = 836,
    fx20_signal_pedaldrc = 843,

    fx20_signal_preset_8 = 844,
    fx20_signal_preset_7,
    fx20_signal_preset_6,
    fx20_signal_preset_5,
    fx20_signal_preset_4,
    fx20_signal_preset_3,
    fx20_signal_preset_2,
    fx20_signal_preset_1,
    fx20_signal_preset_r,
    fx20_signal_preset_d,
    fx20_signal_preset_c,
    fx20_signal_preset_m,

    fx20_signal_symphonic_lorch = 856,
    fx20_signal_symphonic_uorch,
    fx20_signal_symphonic_lcombi,
    fx20_signal_symphonic_ucombi,

    fx20_signal_tremolo_lorch = 860,
    fx20_signal_tremolo_uorch,
    fx20_signal_tremolo_lcombi,
    fx20_signal_tremolo_ucombi,

    fx20_signal_effect_tremolo = 864,
    fx20_signal_effect_symphonic,
    fx20_signal_effect_chorus,
    fx20_signal_effect_celeste,
    fx20_signal_effect_reverb,

    fx20_signal_sequence_on = 880,

    fx20_signal_combi_timbrevari = 881,
    fx20_signal_combi_responsefast,

    fx20_signal_tremolo_pedals = 887,
    fx20_signal_tremolo_lower,
    fx20_signal_tremolo_ul,
    fx20_signal_tremolo_upper,
    fx20_signal_tremolo_solo,
    fx20_signal_tremolo_preset,
    fx20_signal_tremolo_player,
    fx20_signal_tremolo_lever

} fx20_controls;
