/**********************************************************
 * MIDI Out Module for Yamaha Electone FX/FS Series organs
 * Tim Singer, 2012
 * Project page: http://tsstech.org/electronics/fxmidi.html
 * 
 * midi.h:  Low-level MIDI communication
 **********************************************************/

//Configure the UART for MIDI operation
void midi_init();

//Generic two- and three-byte MIDI messages
void midi_send_message_1(byte message_and_channel, byte data);
void midi_send_message_2(byte message_and_channel, byte data1, byte data2);

//MIDI message #9: Note status
void midi_send_note_on(char channel, char pitch, char velocity);
void midi_send_note_off(char channel, char pitch);

//MIDI message #A: Aftertouch
void midi_send_channel_aftertouch(char channel, char value);
void midi_reset_channel_aftertouch();

//MIDI message #B: Controller
void midi_send_controller(char channel, char controller, char value);

//MIDI message #C: Patch change
void midi_send_patch_change(char channel, char value);

#define MIDI_NOTE_OFF 0x80
#define MIDI_NOTE_ON  0x90
#define MIDI_POLY_AFTERTOUCH 0xA0
#define MIDI_CONTROLLER 0xB0
#define MIDI_PATCH_CHANGE 0xC0
#define MIDI_CHANNEL_AFTERTOUCH 0xD0
#define MIDI_PITCH_BEND 0xE0
